import io.github.jwharm.javagi.base.GErrorException;
import io.github.jwharm.javagi.gtk.annotations.GtkCallback;
import io.github.jwharm.javagi.gtk.annotations.GtkChild;
import io.github.jwharm.javagi.gtk.annotations.GtkTemplate;
import io.github.jwharm.javagi.gtk.types.TemplateTypes;

import java.io.IOException;
import java.lang.foreign.MemorySegment;

import org.gnome.gio.File;
import org.gnome.gio.ListStore;
import org.gnome.glib.GLib;
import org.gnome.glib.Type;
import org.gnome.gobject.GObject;
import org.gnome.adw.Window;
import org.gnome.gtk.*;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionException;

@GtkTemplate(ui = "/org/gtk/metachecker/window.ui")
public class MetacheckerWindow extends Window {

    private static final Type gtype = TemplateTypes.register(
            MetacheckerWindow.class
    );

    @GtkChild
    public ColumnView colVwResults;

    @GtkCallback(name = "windowShown")
    public void windowShown() {
        var results = new EvaluationResult[]{
                EvaluationResult.create("color", 1),
                EvaluationResult.create("taste", 4),
                EvaluationResult.create("brightness", 2)
        };

        var dataModel = new ListStore<EvaluationResult>(EvaluationResult.gtype);
        for (var evalResult : results) {
            dataModel.append(evalResult);
        }

        var model = new NoSelection<ListStore<EvaluationResult>>(dataModel);
        colVwResults.setModel(model);
    }

    @GtkCallback(name = "lstSetupWidget")
    public void lstSetupWidget(GObject object) {
        var listItem = (ListItem) object;
        var label = new Label("");
        label.setMarginTop(12);
        label.setMarginBottom(12);
        listItem.setChild(label);
    }

    @GtkCallback(name = "lstBindCategoryName")
    public void lstBindCategoryName(GObject object) {
        var listItem = (ListItem) object;
        var label = (Label) listItem.getChild();
        var result = (EvaluationResult) listItem.getItem();
        label.setLabel(result.getCategoryName());
    }

    @GtkCallback(name = "lstBindScore")
    public void lstBindScore(GObject object) {
        var listItem = (ListItem) object;
        var label = (Label) listItem.getChild();
        var result = (EvaluationResult) listItem.getItem();
        label.setLabel(String.valueOf(result.getScore()));
    }

    public static Type getType() {
        return gtype;
    }

    public MetacheckerWindow(MemorySegment address) {
        super(address);
    }

    public static MetacheckerWindow create(Metachecker app) {
        return GObject.newInstance(getType(), "application", app, null);
    }
}
